Learn R Programming

inveRsion (version 1.20.0)

ac: Sample data set of class accuracy

Description

Illustrative output of function accBic. It stores the accuracy of classification of each chromosome into the inverted population and the frequency of the inversion as a for a range of Bic thresholds.

Usage

data(hapCode)

Arguments

Format

The format is: Formal class '"accuracy"' [package "inveRsion"] with 1 slots ..@ out: num bicInt prob ac [1,] 0.0000 0.3180 0.9045 [2,] 142.4209 0.3745 0.9610 [3,] 284.8419 0.3945 0.9810 [4,] 427.2628 0.4130 0.9995 [5,] 569.6838 0.4130 0.9995

Examples

Run this code
data(ac)
ac

Run the code above in your browser using DataLab