Learn R Programming

inveRsion (version 1.20.0)

accBic: accBic computes "accuracy" from "inversionList"

Description

accBic computes the accuracy of the classification of chromosomes into previously known inverted and non-inverted populations. The classification is obtained from a majority vote of the classifications produced by the trial segment models whose BIC is greater than a given threshold.

Usage

accBic(object, mem, classFile, nsub, npoints, geno, wROI)

Arguments

object
of class inversionList
mem
vector with the numbering of chromosomes known to have the inversion
classFile
an alternative to mem, it passes the file name containing the numbering of chromosomes known to have the inversion.
nsub
total number of subjects (= 2* total number of chromosomes)
npoints
number of BIC threshold between 0 and max (BIC) for which the accuracy is to be computed
geno
whether the accuracy is assessed for inversion genotype or inversion allele (phased data).
wROI
integer indicating the ROI number to be used. The total number of ROIs are the total number of components in the object list.

Value

accuracy
object of class accuracy

See Also

inversionList, accuracy

Examples

Run this code
data(invList)
memFile <- system.file("extdata", "mem.txt", package = "inveRsion")
ac <- accBic(invList, classFile = memFile, nsub = 1000, npoints = 10)
plot(ac)

Run the code above in your browser using DataLab