| Package: |
| inveRsion |
| Type: |
| Package |
| Version: |
| 1.0 |
| Date: |
| 2010-11-12 |
| License: |
| GPL version 2 or newer |
| LazyLoad: |
| yes |
| Depends: |
| methods, haplo.stats |
setUpGenoDatFile loads the genotype data onto R; HaploCode performs local haplotyping around the candidate brake points of the inversion; sanInv takes trial segments of fixed window size and fits the inversion model, sweeping the whole genome; and listInv summarizes the inversion events.
SS Sindi and BJ Raphael, Identification and frequency estimation of inversion polymorphisms from haplotype data, J Comput Biol. 2010 Mar;17(3):517-31.
PF O'Reilly et al., invertFREGENE: software for simulating inversions in population genetic data, Bioinformatics. 2010 Mar 15;26(6):838-40. Epub 2010 Jan 26.