accBic: accBic computes "accuracy" from "inversionList"
Description
accBic computes the accuracy of the classification of chromosomes into previously known inverted and non-inverted populations. The classification is obtained from a majority vote of the classifications produced by the trial segment models whose BIC is greater than a given threshold.