invList:
Sample data of class inversionList
Description
list of objects of class inversion, each of which contains the information of overlapping segments that cover candidate inversions within a chromosome.
Format
The format is:
Formal class 'inversionList' [package "inveRsion"] with 1 slots
..@ results:List of 1
.. ..$ :Formal class 'inversion' [package "inveRsion"] with 8 slotsDetails
The object is constructed with the function listInv